@@ -400,11 +400,24 @@ class AMLPipelineHelper:
             if isinstance(getattr(module_instance.outputs, a), Output)
         ]
         if not datastore_name:
-            datastore_name = (
-                self.config.compute.compliant_datastore
-                if compliant
-                else self.config.compute.noncompliant_datastore
-            )
+            if compliant:
+                component_name = self._get_component_name_from_instance(module_instance)
+                if self.module_loader.is_local(component_name):
+                    datastore_name = self.config.compute.dc_datastore
+                    if not datastore_name:
+                        if self.is_eyesoff():
+                            raise UserErrorException(
+                                "Please specify `dc_datastore` in your compute yaml so that local components can write to it."
+                            )
+                        else:
+                            log.warn(
+                                "We recommend specifying `dc_datastore` in your compute yaml so that local components can write to it. Using `compliant_datastore` for now."
+                            )
+                            datastore_name = self.config.compute.compliant_datastore
+                else:
+                    datastore_name = self.config.compute.compliant_datastore
+            else:
+                datastore_name = self.config.compute.noncompliant_datastore
         for output_key in output_names:
             output_instance = getattr(module_instance.outputs, output_key)
             if output_mode is None:
@@ -418,14 +431,6 @@ class AMLPipelineHelper:
                 f"Configured output {output_key} to use mode {output_mode} and datastore {datastore_name}"
             )
 
-    def _get_dc_datastore(self):
-        if self.config.compute.dc_datastore:
-            return self.config.compute.dc_datastore
-        else:
-            raise UserErrorException(
-                "Please specify `compute.dc_datastore` in your compute yaml."
-            )
-
     def _apply_windows_runsettings(
         self,
         module_name,
@@ -436,6 +441,7 @@ class AMLPipelineHelper:
         process_count_per_node=None,
         input_mode=None,
         output_mode=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for a windows module.
@@ -457,11 +463,6 @@ class AMLPipelineHelper:
                 if target is not None
                 else self.config.compute.windows_cpu_dc_target
             )
-            if (
-                self.config.compute.hdi_dc_target
-                or self.config.compute.synapse_dc_target
-            ):
-                datastore_name = self._get_dc_datastore()
         else:
             target = (
                 target
@@ -545,7 +546,6 @@ class AMLPipelineHelper:
                 raise Exception(
                     f"Your HDI component {module_name} is using local version. Please specify hdi_dc_target"
                 )
-            datastore_name = self._get_dc_datastore()
         else:
             target = (
                 target if target is not None else self.config.compute.hdi_prod_target
@@ -638,7 +638,6 @@ class AMLPipelineHelper:
             target = (
                 target if target is not None else self.config.compute.synapse_dc_target
             )
-            datastore_name = self._get_dc_datastore()
         else:
             target = (
                 target
@@ -766,11 +765,6 @@ class AMLPipelineHelper:
                     _target = self.config.compute.linux_gpu_dc_target
                 else:
                     _target = self.config.compute.linux_cpu_dc_target
-            if (
-                self.config.compute.hdi_dc_target
-                or self.config.compute.synapse_dc_target
-            ):
-                datastore_name = self._get_dc_datastore()
         else:
             if windows:
                 if gpu:
@@ -863,11 +857,6 @@ class AMLPipelineHelper:
                 if target is not None
                 else self.config.compute.linux_gpu_dc_target
             )
-            if (
-                self.config.compute.hdi_dc_target
-                or self.config.compute.synapse_dc_target
-            ):
-                datastore_name = self._get_dc_datastore()
             log.info(
                 f"Using target {target} for local code GPU module {module_name} from pipeline class {self.__class__.__name__}"
             )
@@ -886,11 +875,6 @@ class AMLPipelineHelper:
                 if target is not None
                 else self.config.compute.linux_cpu_dc_target
             )
-            if (
-                self.config.compute.hdi_dc_target
-                or self.config.compute.synapse_dc_target
-            ):
-                datastore_name = self._get_dc_datastore()
             log.info(
                 f"Using target {target} for local CPU module {module_name} from pipeline class {self.__class__.__name__}"
             )
@@ -1088,11 +1072,6 @@ class AMLPipelineHelper:
                     target = self.config.compute.linux_gpu_dc_target
                 else:
                     target = self.config.compute.linux_cpu_dc_target
-            if (
-                self.config.compute.hdi_dc_target
-                or self.config.compute.synapse_dc_target
-            ):
-                datastore_name = self._get_dc_datastore()
         else:
             if windows:
                 if gpu:
@@ -1124,10 +1103,9 @@ class AMLPipelineHelper:
 
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
-        if output_mode:
-            self._set_all_outputs_to(
-                module_instance, output_mode, datastore_name=datastore_name
-            )
+        self._set_all_outputs_to(
+            module_instance, output_mode, datastore_name=datastore_name
+        )
 
         if algorithm:
             module_instance.runsettings.sweep.algorithm = algorithm
@@ -1358,6 +1336,7 @@ class AMLPipelineHelper:
                 or str(module_instance.type) == "ScopeComponent"
                 or str(module_instance.type) == "DataTransferComponent"
                 or str(module_instance.type) == "SweepComponent"
+                or str(module_instance.type) == "SparkComponent"
             ):
                 # HDI/scope/datatransfer/sweep modules might not have that environment object
                 windows = False
@@ -1775,7 +1754,11 @@ class AMLPipelineHelper:
             if id not in node_mapping:
                 continue
             node = node_mapping[id]
-            if node.type != "ScopeComponent" and (
+            if not isinstance(node.runsettings.target, str):
+                log.warn(
+                    f"The compute target of node {node.name} is a PipelineParameter. Shrike will not update even if this or the upstream steps use HDI DC or Synapse DC. Please update manually."
+                )
+            elif node.type != "ScopeComponent" and (
                 (hdi_compute and node.runsettings.target == hdi_compute)
                 or (synapse_compute and node.runsettings.target == synapse_compute)
             ):
@@ -1800,7 +1783,12 @@ class AMLPipelineHelper:
                 log.info(
                     f"Writing outputs of {node.name} to dc_datastore {self.config.compute.dc_datastore}"
                 )
-                if node.runsettings.target == self.config.compute.hdi_prod_target:
+                if not isinstance(node.runsettings.target, str):
+                    log.info(
+                        f"Node {node.name}'s target is a PipelineParameter, skipping."
+                    )
+                    continue
+                elif node.runsettings.target == self.config.compute.hdi_prod_target:
                     node.runsettings.configure(target=self.config.compute.hdi_dc_target)
                 elif (
                     node.runsettings.target == self.config.compute.linux_cpu_prod_target
@@ -1890,10 +1878,11 @@ class AMLPipelineHelper:
         log.info("Creating Pipeline Instance...")
         pipeline = self.pipeline_instance(pipeline_function, self.config)
 
-        log.info(
-            "Overriding compute target if upstream steps use HDI DC or Synapse DC..."
-        )
-        pipeline = self._update_dc_configs(pipeline)
+        if self.is_eyesoff():
+            log.info(
+                "Overriding compute target if upstream steps use HDI DC or Synapse DC..."
+            )
+            pipeline = self._update_dc_configs(pipeline)
 
         if not self.config.run.skip_validation:
             log.info("Validating...")
